@@ -10,25 +10,25 @@
 #ifdef _WIN32
 #include <windows.h>
 #include <io.h>
-#else
-#include <unistd.h>
 #endif
 #include "viewport.h"
 #include "draw.h"
+#include <cgraph/alloc.h>
 #include <common/color.h>
 #include <glade/glade.h>
 #include "gui.h"
 #include "menucallbacks.h"
 #include <stddef.h>
+#include <stdbool.h>
 #include <string.h>
 #include "glcompui.h"
 #include "gltemplate.h"
 #include <common/colorprocs.h>
-#include <common/memory.h>
 #include "topviewsettings.h"
 #include "arcball.h"
 #include "hotkeymap.h"
 #include "topviewfuncs.h"
+#include <cgraph/exit.h>
 #include <cgraph/strcasecmp.h>
 
 
@@ -38,15 +38,9 @@ ViewInfo *view;
 /* these two global variables should be wrapped in something else */
 GtkMessageDialog *Dlg;
 
-static void clear_viewport(ViewInfo * view)
-{
-    /*free topview if there is one */
-    if (view->activeGraph >= 0)
-    {
-	freeSmGraph(view->g[view->activeGraph],view->Topview);
-    }
-    if (view->graphCount)
-	agclose(view->g[view->activeGraph]);
+static void clear_viewport(ViewInfo *vi) {
+    if (vi->graphCount)
+	agclose(vi->g[vi->activeGraph]);
 }
 static void *get_glut_font(int ind)
 {
@@ -76,171 +70,138 @@ static void *get_glut_font(int ind)
 
 }
 
-int close_graph(ViewInfo * view, int graphid)
-{
-    if (view->activeGraph < 0)
-	return 1;
-    clear_viewport(view);
-    return 1;
-
+void close_graph(ViewInfo *vi) {
+    if (vi->activeGraph < 0)
+	return;
+    clear_viewport(vi);
 }
 
-char *get_attribute_value(char *attr, ViewInfo * view, Agraph_t * g)
-{
+char *get_attribute_value(char *attr, ViewInfo *vi, Agraph_t *g) {
     char *buf;
     buf = agget(g, attr);
-    if ((!buf) || (*buf == '\0'))
-	buf = agget(view->systemGraphs.def_attrs, attr);
+    if (!buf || *buf == '\0')
+	buf = agget(vi->systemGraphs.def_attrs, attr);
     return buf;
 }
 
-void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
-{
+void set_viewport_settings_from_template(ViewInfo *vi, Agraph_t *g) {
     gvcolor_t cl;
     char *buf;
-    colorxlate(get_attribute_value("bordercolor", view, g), &cl,
+    colorxlate(get_attribute_value("bordercolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->borderColor.R = (float) cl.u.RGBA[0];
-    view->borderColor.G = (float) cl.u.RGBA[1];
-    view->borderColor.B = (float) cl.u.RGBA[2];
+    vi->borderColor.R = (float)cl.u.RGBA[0];
+    vi->borderColor.G = (float)cl.u.RGBA[1];
+    vi->borderColor.B = (float)cl.u.RGBA[2];
 
-    view->borderColor.A =
-	(float) atof(get_attribute_value("bordercoloralpha", view, g));
+    vi->borderColor.A =
+	(float)atof(get_attribute_value("bordercoloralpha", vi, g));
 
-    view->bdVisible = atoi(get_attribute_value("bordervisible", view, g));
+    vi->bdVisible = atoi(get_attribute_value("bordervisible", vi, g));
 
-    buf = get_attribute_value("gridcolor", view, g);
+    buf = get_attribute_value("gridcolor", vi, g);
     colorxlate(buf, &cl, RGBA_DOUBLE);
-    view->gridColor.R = (float) cl.u.RGBA[0];
-    view->gridColor.G = (float) cl.u.RGBA[1];
-    view->gridColor.B = (float) cl.u.RGBA[2];
-    view->gridColor.A =
-	(float) atof(get_attribute_value("gridcoloralpha", view, g));
+    vi->gridColor.R = (float)cl.u.RGBA[0];
+    vi->gridColor.G = (float)cl.u.RGBA[1];
+    vi->gridColor.B = (float)cl.u.RGBA[2];
+    vi->gridColor.A =
+	(float) atof(get_attribute_value("gridcoloralpha", vi, g));
 
-    view->gridSize = (float) atof(buf =
-				  get_attribute_value("gridsize", view,
-						      g));
+    vi->gridSize = (float)atof(buf = get_attribute_value("gridsize", vi, g));
 
-    view->defaultnodeshape = atoi(buf =
-				  get_attribute_value("defaultnodeshape",
-						      view, g));
-
-    view->gridVisible = atoi(get_attribute_value("gridvisible", view, g));
+    vi->gridVisible = atoi(get_attribute_value("gridvisible", vi, g));
 
     //background color , default white
-    colorxlate(get_attribute_value("bgcolor", view, g), &cl, RGBA_DOUBLE);
+    colorxlate(get_attribute_value("bgcolor", vi, g), &cl, RGBA_DOUBLE);
 
-    view->bgColor.R = (float) cl.u.RGBA[0];
-    view->bgColor.G = (float) cl.u.RGBA[1];
-    view->bgColor.B = (float) cl.u.RGBA[2];
-    view->bgColor.A = (float) 1;
+    vi->bgColor.R = (float)cl.u.RGBA[0];
+    vi->bgColor.G = (float)cl.u.RGBA[1];
+    vi->bgColor.B = (float)cl.u.RGBA[2];
+    vi->bgColor.A = 1.0f;
 
     //selected nodes are drawn with this color
-    colorxlate(get_attribute_value("selectednodecolor", view, g), &cl,
+    colorxlate(get_attribute_value("selectednodecolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->selectedNodeColor.R = (float) cl.u.RGBA[0];
-    view->selectedNodeColor.G = (float) cl.u.RGBA[1];
-    view->selectedNodeColor.B = (float) cl.u.RGBA[2];
-    view->selectedNodeColor.A = (float)
-	atof(get_attribute_value("selectednodecoloralpha", view, g));
+    vi->selectedNodeColor.R = (float)cl.u.RGBA[0];
+    vi->selectedNodeColor.G = (float)cl.u.RGBA[1];
+    vi->selectedNodeColor.B = (float)cl.u.RGBA[2];
+    vi->selectedNodeColor.A = (float)
+	atof(get_attribute_value("selectednodecoloralpha", vi, g));
     //selected edge are drawn with this color
-    colorxlate(get_attribute_value("selectededgecolor", view, g), &cl,
+    colorxlate(get_attribute_value("selectededgecolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->selectedEdgeColor.R = (float) cl.u.RGBA[0];
-    view->selectedEdgeColor.G = (float) cl.u.RGBA[1];
-    view->selectedEdgeColor.B = (float) cl.u.RGBA[2];
-    view->selectedEdgeColor.A = (float)
-	atof(get_attribute_value("selectededgecoloralpha", view, g));
+    vi->selectedEdgeColor.R = (float)cl.u.RGBA[0];
+    vi->selectedEdgeColor.G = (float)cl.u.RGBA[1];
+    vi->selectedEdgeColor.B = (float)cl.u.RGBA[2];
+    vi->selectedEdgeColor.A = (float)
+	atof(get_attribute_value("selectededgecoloralpha", vi, g));
 
-    colorxlate(get_attribute_value("highlightednodecolor", view, g), &cl,
+    colorxlate(get_attribute_value("highlightednodecolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->highlightedNodeColor.R = (float) cl.u.RGBA[0];
-    view->highlightedNodeColor.G = (float) cl.u.RGBA[1];
-    view->highlightedNodeColor.B = (float) cl.u.RGBA[2];
-    view->highlightedNodeColor.A = (float)
-	atof(get_attribute_value("highlightednodecoloralpha", view, g));
+    vi->highlightedNodeColor.R = (float)cl.u.RGBA[0];
+    vi->highlightedNodeColor.G = (float)cl.u.RGBA[1];
+    vi->highlightedNodeColor.B = (float)cl.u.RGBA[2];
+    vi->highlightedNodeColor.A = (float)
+	atof(get_attribute_value("highlightednodecoloralpha", vi, g));
 
     buf = agget(g, "highlightededgecolor");
-    colorxlate(get_attribute_value("highlightededgecolor", view, g), &cl,
+    colorxlate(get_attribute_value("highlightededgecolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->highlightedEdgeColor.R = (float) cl.u.RGBA[0];
-    view->highlightedEdgeColor.G = (float) cl.u.RGBA[1];
-    view->highlightedEdgeColor.B = (float) cl.u.RGBA[2];
-    view->highlightedEdgeColor.A = (float)
-	atof(get_attribute_value("highlightededgecoloralpha", view, g));
-    view->defaultnodealpha = (float)
-	atof(get_attribute_value("defaultnodealpha", view, g));
+    vi->highlightedEdgeColor.R = (float)cl.u.RGBA[0];
+    vi->highlightedEdgeColor.G = (float)cl.u.RGBA[1];
+    vi->highlightedEdgeColor.B = (float)cl.u.RGBA[2];
+    vi->highlightedEdgeColor.A = (float)
+	atof(get_attribute_value("highlightededgecoloralpha", vi, g));
+    vi->defaultnodealpha = (float)
+	atof(get_attribute_value("defaultnodealpha", vi, g));
 
-    view->defaultedgealpha = (float)
-	atof(get_attribute_value("defaultedgealpha", view, g));
+    vi->defaultedgealpha = (float)
+	atof(get_attribute_value("defaultedgealpha", vi, g));
 
 
 
     /*default line width */
-    view->LineWidth =
-	(float) atof(get_attribute_value("defaultlinewidth", view, g));
-    view->FontSize =
-	(float) atof(get_attribute_value("defaultfontsize", view, g));
+    vi->LineWidth =
+	(float) atof(get_attribute_value("defaultlinewidth", vi, g));
 
-    view->topviewusermode = atoi(get_attribute_value("usermode", view, g));
-    get_attribute_value("defaultmagnifierwidth", view, g);
-    view->mg.width =
-	atoi(get_attribute_value("defaultmagnifierwidth", view, g));
-    view->mg.height =
-	atoi(get_attribute_value("defaultmagnifierheight", view, g));
+    vi->drawnodes = atoi(get_attribute_value("drawnodes", vi, g));
+    vi->drawedges = atoi(get_attribute_value("drawedges", vi, g));
+    vi->drawnodelabels=atoi(get_attribute_value("labelshownodes", vi, g));
+    vi->drawedgelabels=atoi(get_attribute_value("labelshowedges", vi, g));
+    vi->nodeScale=atof(get_attribute_value("nodesize", vi, g))*.30;
 
-    view->mg.kts =
-	(float) atof(get_attribute_value("defaultmagnifierkts", view, g));
-
-    view->fmg.constantR =
-	atoi(get_attribute_value
-	     ("defaultfisheyemagnifierradius", view, g));
-
-    view->fmg.fisheye_distortion_fac =
-	atoi(get_attribute_value
-	     ("defaultfisheyemagnifierdistort", view, g));
-    view->drawnodes = atoi(get_attribute_value("drawnodes", view, g));
-    view->drawedges = atoi(get_attribute_value("drawedges", view, g));
-    view->drawnodelabels=atoi(get_attribute_value("labelshownodes", view, g));
-    view->drawedgelabels=atoi(get_attribute_value("labelshowedges", view, g));
-    view->nodeScale=atof(get_attribute_value("nodesize", view, g))*.30;
-
-    view->glutfont =
-	get_glut_font(atoi(get_attribute_value("labelglutfont", view, g)));
-    colorxlate(get_attribute_value("nodelabelcolor", view, g), &cl,
+    vi->glutfont =
+	get_glut_font(atoi(get_attribute_value("labelglutfont", vi, g)));
+    colorxlate(get_attribute_value("nodelabelcolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->nodelabelcolor.R = (float) cl.u.RGBA[0];
-    view->nodelabelcolor.G = (float) cl.u.RGBA[1];
-    view->nodelabelcolor.B = (float) cl.u.RGBA[2];
-    view->nodelabelcolor.A =
-	(float) atof(get_attribute_value("defaultnodealpha", view, g));
-    colorxlate(get_attribute_value("edgelabelcolor", view, g), &cl,
+    vi->nodelabelcolor.R = (float)cl.u.RGBA[0];
+    vi->nodelabelcolor.G = (float)cl.u.RGBA[1];
+    vi->nodelabelcolor.B = (float)cl.u.RGBA[2];
+    vi->nodelabelcolor.A =
+	(float) atof(get_attribute_value("defaultnodealpha", vi, g));
+    colorxlate(get_attribute_value("edgelabelcolor", vi, g), &cl,
 	       RGBA_DOUBLE);
-    view->edgelabelcolor.R = (float) cl.u.RGBA[0];
-    view->edgelabelcolor.G = (float) cl.u.RGBA[1];
-    view->edgelabelcolor.B = (float) cl.u.RGBA[2];
-    view->edgelabelcolor.A =
-	(float) atof(get_attribute_value("defaultedgealpha", view, g));
-    view->labelwithdegree =
-	atoi(get_attribute_value("labelwithdegree", view, g));
-    view->labelnumberofnodes =
-	atof(get_attribute_value("labelnumberofnodes", view, g));
-    view->labelshownodes =
-	atoi(get_attribute_value("labelshownodes", view, g));
-    view->labelshowedges =
-	atoi(get_attribute_value("labelshowedges", view, g));
-    view->colschms =
+    vi->edgelabelcolor.R = (float)cl.u.RGBA[0];
+    vi->edgelabelcolor.G = (float)cl.u.RGBA[1];
+    vi->edgelabelcolor.B = (float)cl.u.RGBA[2];
+    vi->edgelabelcolor.A =
+	(float) atof(get_attribute_value("defaultedgealpha", vi, g));
+    vi->labelwithdegree = atoi(get_attribute_value("labelwithdegree", vi, g));
+    vi->labelnumberofnodes =
+	atof(get_attribute_value("labelnumberofnodes", vi, g));
+    vi->labelshownodes = atoi(get_attribute_value("labelshownodes", vi, g));
+    vi->labelshowedges = atoi(get_attribute_value("labelshowedges", vi, g));
+    vi->colschms =
 	create_color_theme(atoi
-			   (get_attribute_value("colortheme", view, g)));
-    view->edgerendertype=atoi(get_attribute_value("edgerender", view, g));
+			   (get_attribute_value("colortheme", vi, g)));
 
-
-    if (view->graphCount > 0)
-	glClearColor(view->bgColor.R, view->bgColor.G, view->bgColor.B, view->bgColor.A);	//background color
+    if (vi->graphCount > 0)
+	glClearColor(vi->bgColor.R, vi->bgColor.G, vi->bgColor.B, vi->bgColor.A);	//background color
 }
 
 static gboolean gl_main_expose(gpointer data)
 {
+    (void)data;
+
     if (view->activeGraph >= 0) {
 	if (view->Topview->fisheyeParams.animate == 1)
 	    expose_event(view->drawing_area, NULL, NULL);
@@ -251,166 +212,144 @@ static gboolean gl_main_expose(gpointer data)
 
 static void get_data_dir(void)
 {
-    if (view->template_file) {
-	free(view->template_file);
-    }
-
-    view->template_file = strdup(smyrnaPath("template.dot"));
+    free(view->template_file);
+    view->template_file = gv_strdup(smyrnaPath("template.dot"));
 }
 
-void init_viewport(ViewInfo * view)
-{
+void init_viewport(ViewInfo *vi) {
     FILE *input_file = NULL;
     FILE *input_file2 = NULL;
     static char* path;
     get_data_dir();
-    input_file = fopen(view->template_file, "rb");
+    input_file = fopen(vi->template_file, "rb");
     if (!input_file) {
 	fprintf(stderr,
 		"default attributes template graph file \"%s\" not found\n",
-		view->template_file);
-	exit(-1);
+		vi->template_file);
+	graphviz_exit(-1);
     } 
-    view->systemGraphs.def_attrs = agread(input_file, NULL);
+    vi->systemGraphs.def_attrs = agread(input_file, NULL);
     fclose (input_file);
 
-    if (!view->systemGraphs.def_attrs) {
+    if (!vi->systemGraphs.def_attrs) {
 	fprintf(stderr,
 		"could not load default attributes template graph file \"%s\"\n",
-		view->template_file);
-	exit(-1);
+		vi->template_file);
+	graphviz_exit(-1);
     }
     if (!path)
 	path = smyrnaPath("attr_widgets.dot");
     input_file2 = fopen(path, "rb");
     if (!input_file2) {
 	fprintf(stderr,	"default attributes template graph file \"%s\" not found\n",smyrnaPath("attr_widgets.dot"));
-	exit(-1);
+	graphviz_exit(-1);
 
     }
-    view->systemGraphs.attrs_widgets = agread(input_file2, NULL);
+    vi->systemGraphs.attrs_widgets = agread(input_file2, NULL);
     fclose (input_file2);
-    if (!(view->systemGraphs.attrs_widgets )) {
+    if (!vi->systemGraphs.attrs_widgets) {
 	fprintf(stderr,"could not load default attribute widgets graph file \"%s\"\n",smyrnaPath("attr_widgets.dot"));
-	exit(-1);
+	graphviz_exit(-1);
     }
     //init graphs
-    view->g = NULL;		//no graph, gl screen should check it
-    view->graphCount = 0;	//and disable interactivity if count is zero
+    vi->g = NULL;		//no graph, gl screen should check it
+    vi->graphCount = 0;	//and disable interactivity if count is zero
 
-    view->bdxLeft = 0;
-    view->bdxRight = 500;
-    view->bdyBottom = 0;
-    view->bdyTop = 500;
+    vi->bdxLeft = 0;
+    vi->bdxRight = 500;
+    vi->bdyBottom = 0;
+    vi->bdyTop = 500;
 
-    view->borderColor.R = 1;
-    view->borderColor.G = 0;
-    view->borderColor.B = 0;
-    view->borderColor.A = 1;
+    vi->borderColor.R = 1;
+    vi->borderColor.G = 0;
+    vi->borderColor.B = 0;
+    vi->borderColor.A = 1;
 
-    view->bdVisible = 1;	//show borders red
+    vi->bdVisible = 1;	//show borders red
 
-    view->gridSize = 10;
-    view->gridColor.R = 0.5;
-    view->gridColor.G = 0.5;
-    view->gridColor.B = 0.5;
-    view->gridColor.A = 1;
-    view->gridVisible = 0;	//show grids in light gray
+    vi->gridSize = 10;
+    vi->gridColor.R = 0.5;
+    vi->gridColor.G = 0.5;
+    vi->gridColor.B = 0.5;
+    vi->gridColor.A = 1;
+    vi->gridVisible = 0;	//show grids in light gray
 
     //mouse mode=pan
     //pen color
-    view->penColor.R = 0;
-    view->penColor.G = 0;
-    view->penColor.B = 0;
-    view->penColor.A = 1;
+    vi->penColor.R = 0;
+    vi->penColor.G = 0;
+    vi->penColor.B = 0;
+    vi->penColor.A = 1;
 
-    view->fillColor.R = 1;
-    view->fillColor.G = 0;
-    view->fillColor.B = 0;
-    view->fillColor.A = 1;
+    vi->fillColor.R = 1;
+    vi->fillColor.G = 0;
+    vi->fillColor.B = 0;
+    vi->fillColor.A = 1;
     //background color , default white
-    view->bgColor.R = 1;
-    view->bgColor.G = 1;
-    view->bgColor.B = 1;
-    view->bgColor.A = 1;
+    vi->bgColor.R = 1;
+    vi->bgColor.G = 1;
+    vi->bgColor.B = 1;
+    vi->bgColor.A = 1;
 
     //selected objets are drawn with this color
-    view->selectedNodeColor.R = 1;
-    view->selectedNodeColor.G = 0;
-    view->selectedNodeColor.B = 0;
-    view->selectedNodeColor.A = 1;
+    vi->selectedNodeColor.R = 1;
+    vi->selectedNodeColor.G = 0;
+    vi->selectedNodeColor.B = 0;
+    vi->selectedNodeColor.A = 1;
 
     //default line width;
-    view->LineWidth = 1;
+    vi->LineWidth = 1;
 
-    //default view settings , camera is not active
-    view->panx = 0;
-    view->pany = 0;
-    view->panz = 0;
+    //default view settings, camera is not active
+    vi->panx = 0;
+    vi->pany = 0;
+    vi->panz = 0;
 
+    vi->zoom = -20;
 
-    view->zoom = -20;
-    view->FontSize = 52;
-
-    view->topviewusermode = TOP_VIEW_USER_NOVICE_MODE;	//for demo
-    view->mg.active = 0;
-    view->mg.x = 0;
-    view->mg.y = 0;
-    view->mg.width = DEFAULT_MAGNIFIER_WIDTH;
-    view->mg.height = DEFAULT_MAGNIFIER_HEIGHT;
-    view->mg.kts = DEFAULT_MAGNIFIER_KTS;
-    view->fmg.constantR = DEFAULT_FISHEYE_MAGNIFIER_RADIUS;
-    view->fmg.active = 0;
-    view->mouse.down = 0;
-    view->activeGraph = -1;
-    view->Topview = GNEW(topview);
-    view->Topview->fisheyeParams.fs = 0;
-    view->Topview->xDot=NULL;
+    vi->mouse.down = 0;
+    vi->activeGraph = -1;
+    vi->Topview = gv_alloc(sizeof(topview));
+    vi->Topview->fisheyeParams.fs = 0;
+    vi->Topview->xDot=NULL;
 
     /* init topfish parameters */
-    view->Topview->fisheyeParams.level.num_fine_nodes = 10;
-    view->Topview->fisheyeParams.level.coarsening_rate = 2.5;
-    view->Topview->fisheyeParams.hier.dist2_limit = 1;
-    view->Topview->fisheyeParams.hier.min_nvtxs = 20;
-    view->Topview->fisheyeParams.repos.rescale = Polar;
-    view->Topview->fisheyeParams.repos.width =
-	(int) (view->bdxRight - view->bdxLeft);
-    view->Topview->fisheyeParams.repos.height =
-	(int) (view->bdyTop - view->bdyBottom);
-    view->Topview->fisheyeParams.repos.margin = 0;
-    view->Topview->fisheyeParams.repos.graphSize = 100;
-    view->Topview->fisheyeParams.repos.distortion = 1.0;
+    vi->Topview->fisheyeParams.level.num_fine_nodes = 10;
+    vi->Topview->fisheyeParams.level.coarsening_rate = 2.5;
+    vi->Topview->fisheyeParams.hier.dist2_limit = 1;
+    vi->Topview->fisheyeParams.repos.rescale = Polar;
+    vi->Topview->fisheyeParams.repos.width = (int)(vi->bdxRight - vi->bdxLeft);
+    vi->Topview->fisheyeParams.repos.height = (int)(vi->bdyTop - vi->bdyBottom);
+    vi->Topview->fisheyeParams.repos.margin = 0;
+    vi->Topview->fisheyeParams.repos.graphSize = 100;
+    vi->Topview->fisheyeParams.repos.distortion = 1.0;
     /*create timer */
-    view->timer = g_timer_new();
-    view->timer2 = g_timer_new();
-    view->timer3 = g_timer_new();
+    vi->timer = g_timer_new();
+    vi->timer2 = g_timer_new();
+    vi->timer3 = g_timer_new();
 
-    g_timer_stop(view->timer);
-    view->active_frame = 0;
-    view->total_frames = 1500;
+    g_timer_stop(vi->timer);
+    vi->active_frame = 0;
+    vi->total_frames = 1500;
     /*add a call back to the main() */
-    g_timeout_add_full((gint) G_PRIORITY_DEFAULT, (guint) 100,
-		       gl_main_expose, NULL, NULL);
-    view->cameras = '\0';;
-    view->camera_count = 0;
-    view->active_camera = -1;
-    set_viewport_settings_from_template(view, view->systemGraphs.def_attrs);
-    view->Topview->Graphdata.GraphFileName = (char *) 0;
-    view->colschms = NULL;
-    view->arcball = NEW(ArcBall_t);
-    view->keymap.down=0;
-    load_mouse_actions (view);
-    view->refresh.color=1;
-    view->refresh.pos=1;
-    view->refresh.selection=1;
-    view->refresh.nodesize=1;
-    view->edgerendertype=0;
-    if(view->guiMode!=GUI_FULLSCREEN)
-	view->guiMode=GUI_WINDOWED;
+    g_timeout_add_full(G_PRIORITY_DEFAULT, 100u, gl_main_expose, NULL, NULL);
+    vi->cameras = NULL;
+    vi->camera_count = 0;
+    vi->active_camera = -1;
+    set_viewport_settings_from_template(vi, vi->systemGraphs.def_attrs);
+    vi->Topview->Graphdata.GraphFileName = NULL;
+    vi->colschms = NULL;
+    vi->arcball = gv_alloc(sizeof(ArcBall_t));
+    vi->keymap.down=0;
+    load_mouse_actions(vi);
+    vi->refresh.color=1;
+    vi->refresh.pos=1;
+    vi->refresh.selection=1;
+    if(vi->guiMode!=GUI_FULLSCREEN)
+	vi->guiMode=GUI_WINDOWED;
 
     /*create glcomp menu system */
-    view->widgets = glcreate_gl_topview_menu();
-
+    vi->widgets = glcreate_gl_topview_menu();
 }
 
 
@@ -446,7 +385,7 @@ static Agraph_t *loadGraph(char *filename)
 	agclose (g);
 	return 0;
     }
-    view->Topview->Graphdata.GraphFileName = strdup(filename);
+    view->Topview->Graphdata.GraphFileName = gv_strdup(filename);
     return g;
 }
 
@@ -487,7 +426,7 @@ void updateRecord (Agraph_t* g)
 static void
 graphRecord (Agraph_t* g)
 {
-    agbindrec(g, "graphRec", sizeof(graphRec), 1);
+    agbindrec(g, "graphRec", sizeof(graphRec), true);
 
     GG_nodelabelcolor(g) = agattr (g, AGRAPH, "nodelabelcolor", 0);
     GG_edgelabelcolor(g) = agattr (g, AGRAPH, "edgelabelcolor", 0);
@@ -500,14 +439,13 @@ graphRecord (Agraph_t* g)
     updateRecord (g);
 }
 
-void refreshViewport(int doClear)
+void refreshViewport(void)
 {
     Agraph_t *graph = view->g[view->activeGraph];
     view->refresh.color=1;
-    view->refresh.nodesize=1;
     view->refresh.pos=1;
     view->refresh.selection=1;
-    load_settings_from_graph(graph);
+    load_settings_from_graph();
 
     if(view->guiMode!=GUI_FULLSCREEN)
 	update_graph_from_settings(graph);
@@ -518,23 +456,23 @@ void refreshViewport(int doClear)
     expose_event(view->drawing_area, NULL, NULL);
 }
 
-static void activate(int id, int doClear)
+static void activate(int id)
 {
     view->activeGraph = id;
-    refreshViewport(doClear);
+    refreshViewport();
 }
 
 int add_graph_to_viewport(Agraph_t * graph, char *id)
 {
     if (graph) {
+	view->g = gv_recalloc(view->g, view->graphCount, view->graphCount + 1,
+	                      sizeof(Agraph_t*));
 	view->graphCount = view->graphCount + 1;
-	view->g = realloc(view->g,
-				  sizeof(Agraph_t *) * view->graphCount);
 	view->g[view->graphCount - 1] = graph;
 
 	gtk_combo_box_append_text(view->graphComboBox, id);
 	gtk_combo_box_set_active(view->graphComboBox,view->graphCount-1);
-	activate(view->graphCount - 1, 0);
+	activate(view->graphCount - 1);
 	return 1;
     } else {
 	return 0;
@@ -543,10 +481,10 @@ int add_graph_to_viewport(Agraph_t * graph, char *id)
 }
 void switch_graph(int graphId)
 {
-    if ((graphId >= view->graphCount) || (graphId < 0))
+    if (graphId >= view->graphCount || graphId < 0)
 	return;			/*wrong entry */
     else
-	activate(graphId, 0);
+	activate(graphId);
 }
 
 /* save_graph_with_file_name:
@@ -606,8 +544,7 @@ int save_as_graph(void)
 {
     //check if there is an active graph
     if (view->activeGraph > -1) {
-	GtkWidget *dialog;
-	dialog = gtk_file_chooser_dialog_new("Save File",
+	GtkWidget *dialog = gtk_file_chooser_dialog_new("Save File",
 					     NULL,
 					     GTK_FILE_CHOOSER_ACTION_SAVE,
 					     GTK_STOCK_CANCEL,
@@ -617,8 +554,7 @@ int save_as_graph(void)
 	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER
 						       (dialog), TRUE);
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
-	    char *filename;
-	    filename =
+	    char *filename =
 		gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 	    save_graph_with_file_name(view->g[view->activeGraph],
 				      filename);
@@ -641,7 +577,7 @@ void glexpose(void)
 
 static float interpol(float minv, float maxv, float minc, float maxc, float x)
 {
-    return ((x - minv) * (maxc - minc) / (maxv - minv) + minc);
+    return (x - minv) * (maxc - minc) / (maxv - minv) + minc;
 }
 
 void getcolorfromschema(colorschemaset * sc, float l, float maxl,
@@ -734,19 +670,17 @@ static colordata palette[] = {
 
 static colorschemaset *create_color_theme(int themeid)
 {
-    colorschemaset *s;
-
-    if ((themeid < 0) || (NUM_SCHEMES <= themeid)) {
+    if (themeid < 0 || (int)NUM_SCHEMES <= themeid) {
 	fprintf (stderr, "colorschemaset: illegal themeid %d\n", themeid);
 	return view->colschms;
     }
 
-    s = NEW(colorschemaset);
+    colorschemaset *s = gv_alloc(sizeof(colorschemaset));
     if (view->colschms)
 	clear_color_theme(view->colschms);
 
     s->schemacount = palette[themeid].cnt;
-    s->s = N_NEW(s->schemacount,colorschema);
+    s->s = gv_calloc(s->schemacount, sizeof(colorschema));
     set_color_theme_color(s, palette[themeid].colors);
 
     return s;
