@@ -10,20 +10,14 @@
 
 #pragma once
 
-#ifndef NOTUSED
-#define NOTUSED(var) (void) var
-#endif
-
-#ifndef NIL
-#define NIL(type)  ((type)0)
-#endif
+#include <stdbool.h>
 
 #define isPinned(n)     (ND_pinned(n) == P_PIN)
 #define hasPos(n)       (ND_pinned(n) > 0)
 #define isFixed(n)      (ND_pinned(n) > P_SET)
 
 #define CL_EDGE_TAG "cl_edge_info"
-#define SET_CLUST_NODE(n) (ND_clustnode(n) = TRUE)
+#define SET_CLUST_NODE(n) (ND_clustnode(n) = true)
 #define IS_CLUST_NODE(n)  (ND_clustnode(n))
 #define HAS_CLUST_EDGE(g) (aggetrec(g, CL_EDGE_TAG, FALSE))
 #define EDGE_TYPE(g) (GD_flags(g) & (7 << 1))
