@@ -16,7 +16,8 @@
  */
 
 #include "config.h"
-
+#include <cgraph/agxbuf.h>
+#include <ctype.h>
 #include <expr/exlib.h>
 #include <stddef.h>
 #include <stdio.h>
@@ -324,7 +325,6 @@ extoken_fn(Expr_t* ex)
 	int	c;
 	char*	s;
 	int	q;
-	int		b;
 	char*		e;
 	Dt_t*		v;
 
@@ -463,7 +463,7 @@ extoken_fn(Expr_t* ex)
 			if (!ex->linewrap && !(ex->disc->flags & EX_PURE))
 			{
 				s = ex->linep - 1;
-				while (s > ex->line && isspace(*(s - 1)))
+				while (s > ex->line && isspace((int)*(s - 1)))
 					s--;
 				if (s == ex->line)
 				{
@@ -482,7 +482,7 @@ extoken_fn(Expr_t* ex)
 					{
 						if (extoken_fn(ex) != STRING)
 							exerror("#%s: string argument expected", s);
-						else if (!expush(ex, ex_lval.string, 1, NULL, NULL))
+						else if (!expush(ex, ex_lval.string, 1, NULL))
 						{
 							setcontext(ex);
 							goto again;
@@ -495,13 +495,13 @@ extoken_fn(Expr_t* ex)
 		case '\'':
 		case '"':
 			q = c;
-			sfstrseek(ex->tmp, 0, SEEK_SET);
+			agxbclear(&ex->tmp);
 			ex->input->nesting++;
 			while ((c = lex(ex)) != q)
 			{
 				if (c == '\\')
 				{
-					sfputc(ex->tmp, c);
+					agxbputc(&ex->tmp, '\\');
 					c = lex(ex);
 				}
 				if (!c)
@@ -515,10 +515,10 @@ extoken_fn(Expr_t* ex)
 						error_info.line++;
 					else error_info.line = 2;
 				}
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 			}
 			ex->input->nesting--;
-			s = exstash(ex->tmp, NULL);
+			s = agxbuse(&ex->tmp);
 			if (q == '"' || (ex->disc->flags & EX_CHARSTRING))
 			{
 				if (!(ex_lval.string = vmstrdup(ex->vm, s)))
@@ -531,52 +531,40 @@ extoken_fn(Expr_t* ex)
 		case '.':
 			if (isdigit(c = lex(ex)))
 			{
-				sfstrseek(ex->tmp, 0, SEEK_SET);
-				sfputc(ex->tmp, '0');
-				sfputc(ex->tmp, '.');
+				agxbclear(&ex->tmp);
+				agxbput(&ex->tmp, "0.");
 				goto floating;
 			}
 			exunlex(ex, c);
 			return ex_lval.op = '.';
 		case '0': case '1': case '2': case '3': case '4':
-		case '5': case '6': case '7': case '8': case '9':
-			sfstrseek(ex->tmp, 0, SEEK_SET);
-			sfputc(ex->tmp, c);
+		case '5': case '6': case '7': case '8': case '9': {
+			agxbclear(&ex->tmp);
+			agxbputc(&ex->tmp, (char)c);
 			q = INTEGER;
-			b = 0;
+			int b = 0;
 			if ((c = lex(ex)) == 'x' || c == 'X')
 			{
 				b = 16;
-				sfputc(ex->tmp, c);
-				for (;;)
+				agxbputc(&ex->tmp, (char)c);
+				for (c = lex(ex); isxdigit(c); c = lex(ex))
 				{
-					switch (c = lex(ex))
-					{
-					case '0': case '1': case '2': case '3': case '4':
-					case '5': case '6': case '7': case '8': case '9':
-					case 'a': case 'b': case 'c': case 'd': case 'e': case 'f': 
-					case 'A': case 'B': case 'C': case 'D': case 'E': case 'F': 
-						sfputc(ex->tmp, c);
-						continue;
-					}
-					break;
+					agxbputc(&ex->tmp, (char)c);
 				}
 			}
 			else
 			{
 				while (isdigit(c))
 				{
-					sfputc(ex->tmp, c);
+					agxbputc(&ex->tmp, (char)c);
 					c = lex(ex);
 				}
 				if (c == '#')
 				{
-					sfputc(ex->tmp, c);
-					/* s = exstash(ex->tmp, NULL); */
-					/* b = strtol(s, NULL, 10); */
+					agxbputc(&ex->tmp, (char)c);
 					do
 					{
-						sfputc(ex->tmp, c);
+						agxbputc(&ex->tmp, (char)c);
 					} while (isalnum(c = lex(ex)));
 				}
 				else
@@ -585,28 +573,28 @@ extoken_fn(Expr_t* ex)
 					{
 					floating:
 						q = FLOATING;
-						sfputc(ex->tmp, c);
+						agxbputc(&ex->tmp, (char)c);
 						while (isdigit(c = lex(ex)))
-							sfputc(ex->tmp, c);
+							agxbputc(&ex->tmp, (char)c);
 					}
 					if (c == 'e' || c == 'E')
 					{
 						q = FLOATING;
-						sfputc(ex->tmp, c);
+						agxbputc(&ex->tmp, (char)c);
 						if ((c = lex(ex)) == '-' || c == '+')
 						{
-							sfputc(ex->tmp, c);
+							agxbputc(&ex->tmp, (char)c);
 							c = lex(ex);
 						}
 						while (isdigit(c))
 						{
-							sfputc(ex->tmp, c);
+							agxbputc(&ex->tmp, (char)c);
 							c = lex(ex);
 						}
 					}
 				}
 			}
-			s = exstash(ex->tmp, NULL);
+			s = agxbuse(&ex->tmp);
 			if (q == FLOATING)
 				ex_lval.floating = strtod(s, &e);
 			else
@@ -627,15 +615,16 @@ extoken_fn(Expr_t* ex)
 				goto eof;
 			}
 			return q;
+		}
 		default:
 			if (isalpha(c) || c == '_' || c == '$')
 			{
-				sfstrseek(ex->tmp, 0, SEEK_SET);
-				sfputc(ex->tmp, c);
+				agxbclear(&ex->tmp);
+				agxbputc(&ex->tmp, (char)c);
 				while (isalnum(c = lex(ex)) || c == '_' || c == '$')
-					sfputc(ex->tmp, c);
+					agxbputc(&ex->tmp, (char)c);
 				exunlex(ex, c);
-				s = exstash(ex->tmp, NULL);
+				s = agxbuse(&ex->tmp);
 				/* v = expr.declare ? dtview(ex->symbols, NULL) : (Dt_t*)0; FIX */
 				v = (Dt_t*)0;
 				ex_lval.id = dtmatch(ex->symbols, s);
@@ -707,7 +696,7 @@ extoken_fn(Expr_t* ex)
 						int	t;
 
 						/*UNDENT...*/
-		sfstrseek(ex->tmp, 0, SEEK_SET);
+		agxbclear(&ex->tmp);
 		b = 1;
 		n = 0;
 		po = 0;
@@ -752,7 +741,7 @@ extoken_fn(Expr_t* ex)
 						}
 						if (!b++)
 							goto eof;
-						sfputc(ex->tmp, ' ');
+						agxbputc(&ex->tmp, ' ');
 						break;
 					}
 					break;
@@ -764,12 +753,12 @@ extoken_fn(Expr_t* ex)
 						error_info.line++;
 					else error_info.line = 2;
 					b = 1;
-					sfputc(ex->tmp, '\n');
+					agxbputc(&ex->tmp, '\n');
 					break;
 				default:
 					b = 0;
-					sfputc(ex->tmp, c);
-					sfputc(ex->tmp, q);
+					agxbputc(&ex->tmp, (char)c);
+					agxbputc(&ex->tmp, (char)q);
 					break;
 				}
 				continue;
@@ -778,13 +767,13 @@ extoken_fn(Expr_t* ex)
 					error_info.line++;
 				else error_info.line = 2;
 				b = 1;
-				sfputc(ex->tmp, '\n');
+				agxbputc(&ex->tmp, '\n');
 				continue;
 			case ' ':
 			case '\t':
 				if (!b++)
 					goto eof;
-				sfputc(ex->tmp, ' ');
+				agxbputc(&ex->tmp, ' ');
 				continue;
 			case '(':
 			case '{':
@@ -808,7 +797,7 @@ extoken_fn(Expr_t* ex)
 				}
 				else if (c == po)
 					n++;
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 				continue;
 			case ')':
 			case '}':
@@ -819,7 +808,7 @@ extoken_fn(Expr_t* ex)
 					exunlex(ex, c);
 					break;
 				}
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 				if (c == pc && --n <= 0)
 				{
 					if (t == po)
@@ -831,19 +820,19 @@ extoken_fn(Expr_t* ex)
 				b = 0;
 				if (!n)
 					break;
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 				continue;
 			case '\'':
 			case '"':
 				b = 0;
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 				ex->input->nesting++;
 				q = c;
 				while ((c = lex(ex)) != q)
 				{
 					if (c == '\\')
 					{
-						sfputc(ex->tmp, c);
+						agxbputc(&ex->tmp, '\\');
 						c = lex(ex);
 					}
 					if (!c)
@@ -857,18 +846,18 @@ extoken_fn(Expr_t* ex)
 							error_info.line++;
 						else error_info.line = 2;
 					}
-					sfputc(ex->tmp, c);
+					agxbputc(&ex->tmp, (char)c);
 				}
 				ex->input->nesting--;
 				continue;
 			default:
 				b = 0;
-				sfputc(ex->tmp, c);
+				agxbputc(&ex->tmp, (char)c);
 				continue;
 			}
 			break;
 		}
-		(*ex->disc->reff)(ex, NULL, ex_lval.id, NULL, exstash(ex->tmp, NULL), 0, ex->disc);
+		ex->disc->reff(ex, NULL, ex_lval.id, NULL);
 
 						/*..INDENT*/
 					}
