@@ -20,15 +20,13 @@ extern "C" {
 #include <stdio.h>
 #include <cgraph/cgraph.h>
 
-    extern double Scale;
     extern void outputGraph(Agraph_t *, FILE *, int);
 
     extern void incInd(void);
     extern void decInd(void);
     extern void prIndent(void);
 
-    extern void dump(graph_t * g, int doAll, int doBB);
-    extern void dumpE(graph_t * g, int derived);
+    extern void dump(graph_t *g, int doAll);
     extern void dumpG(graph_t * g, char *fname, int);
 
 #endif
