@@ -13,48 +13,8 @@
 #include <string.h>
 #include <glcomp/glcompdefs.h>
 
-/* at given depth value, tranforms 2d Window location to 3d gl coords*/
-int GetFixedOGLPos(int x, int y, float kts, GLfloat * X, GLfloat * Y,
-		   GLfloat * Z)
-{
-    GLdouble wwinX;
-    GLdouble wwinY;
-    GLdouble wwinZ;
-
-    GLint viewport[4];
-    GLdouble modelview[16];
-    GLdouble projection[16];
-    GLfloat winX, winY;
-    GLdouble posX, posY, posZ;
-
-    /* unused */
-    (void)kts;
-
-    glColor4f(0.0f, 0.0f, 0.0f, 0.001f);
-    glBegin(GL_POINTS);
-    glVertex3f(-100.0f, -100.0f, 1.0f);
-    glEnd();
-
-    glGetDoublev(GL_MODELVIEW_MATRIX, modelview);
-    glGetDoublev(GL_PROJECTION_MATRIX, projection);
-    glGetIntegerv(GL_VIEWPORT, viewport);
-    gluProject(-100.0, -100.0, 1.00, modelview, projection, viewport,
-	       &wwinX, &wwinY, &wwinZ);
-
-    winX = (float) x;
-    winY = (float) viewport[3] - (float) y;
-    gluUnProject(winX, winY, wwinZ, modelview, projection, viewport, &posX,
-		 &posY, &posZ);
-    *X = (GLfloat) posX;
-    *Y = (GLfloat) posY;
-    *Z = (GLfloat) posZ;
-
-    return 1;
-}
-
 /*transforms 2d windows location to 3d gl coords but depth is calculated unlike the previous function*/
-int GetOGLPosRef(int x, int y, float *X, float *Y, float *Z)
-{
+int GetOGLPosRef(int x, int y, float *X, float *Y) {
     GLdouble wwinX;
     GLdouble wwinY;
     GLdouble wwinZ;
@@ -83,7 +43,7 @@ int GetOGLPosRef(int x, int y, float *X, float *Y, float *Z)
 
     *X = (float) posX;
     *Y = (float) posY;
-    *Z = (float) posZ;
+    (void)posZ; // ignore Z that the caller does not need
 
     return 1;
 }
@@ -149,7 +109,6 @@ void to3D(int x, int y, GLfloat * X, GLfloat * Y, GLfloat * Z)
     GLfloat winZ[400];
     GLdouble posX, posY, posZ;
     int idx;
-    static float comp;
 
     glGetDoublev(GL_MODELVIEW_MATRIX, modelview);
     glGetDoublev(GL_PROJECTION_MATRIX, projection);
@@ -160,9 +119,9 @@ void to3D(int x, int y, GLfloat * X, GLfloat * Y, GLfloat * Z)
 
     glReadPixels(x - WIDTH / 2, (int) winY - WIDTH / 2, WIDTH, WIDTH,
 		 GL_DEPTH_COMPONENT, GL_FLOAT, &winZ);
-    comp = -9999999;
+    float comp = -9999999;
     for (idx = 0; idx < WIDTH * WIDTH; idx++) {
-	if ((winZ[idx] > comp) && (winZ[idx] < 1))
+	if (winZ[idx] > comp && winZ[idx] < 1)
 	    comp = winZ[idx];
     }
 
@@ -175,42 +134,6 @@ void to3D(int x, int y, GLfloat * X, GLfloat * Y, GLfloat * Z)
     return;
 }
 
-int GetFixedOGLPoslocal(int x, int y, GLfloat * X, GLfloat * Y,
-			GLfloat * Z)
-{
-    GLdouble wwinX;
-    GLdouble wwinY;
-    GLdouble wwinZ;
-
-    GLint viewport[4];
-    GLdouble modelview[16];
-    GLdouble projection[16];
-    GLfloat winX, winY;
-    GLdouble posX, posY, posZ;
-
-    glGetDoublev(GL_MODELVIEW_MATRIX, modelview);
-    glGetDoublev(GL_PROJECTION_MATRIX, projection);
-    glGetIntegerv(GL_VIEWPORT, viewport);
-
-    glColor4f(0.0f, 0.0f, 0.0f, 0.001f);
-    glBegin(GL_POINTS);
-    glVertex3f(10.0f, 10.0f, 0.0f);
-    glEnd();
-
-    gluProject(10.0, 10.0, 1.00, modelview, projection, viewport, &wwinX,
-	       &wwinY, &wwinZ);
-
-    winX = (float) x;
-    winY = (float) viewport[3] - (float) y;
-    gluUnProject(winX, winY, wwinZ, modelview, projection, viewport, &posX,
-		 &posY, &posZ);
-    *X = (GLfloat) posX;
-    *Y = (GLfloat) posY;
-    *Z = (GLfloat) posZ;
-
-    return 1;
-}
-
 #include <math.h>
 
 static glCompPoint sub(glCompPoint p, glCompPoint q)
@@ -223,7 +146,7 @@ static glCompPoint sub(glCompPoint p, glCompPoint q)
 
 static double dot(glCompPoint p, glCompPoint q)
 {
-    return (p.x * q.x + p.y * q.y + p.z * q.z);
+    return p.x * q.x + p.y * q.y + p.z * q.z;
 }
 
 static double len(glCompPoint p)
@@ -243,7 +166,7 @@ static glCompPoint blend(glCompPoint p, glCompPoint q, float m)
 
 static double dist(glCompPoint p, glCompPoint q)
 {
-    return (len(sub(p, q)));
+    return len(sub(p, q));
 }
 
 /*
@@ -271,37 +194,6 @@ double point_to_lineseg_dist(glCompPoint p, glCompPoint a, glCompPoint b)
     return dist(p, q);
 }
 
-void replacestr(char *source, char **target)
-{
-
-    free(*target);
-    *target = strdup(source);
-}
-
-void glCompSelectionBox(glCompSet * s)
-{
-    static GLfloat x, y, w, h;
-
-    x = s->mouse.pos.x;
-    y = s->mouse.pos.y;
-    w = s->mouse.dragX;
-    h = s->mouse.dragY;
-    printf("%f %f  %f  %f \n", x, y, w, h);
-    glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
-
-    glBegin(GL_POLYGON);
-    glVertex2f(0, 0);
-    glVertex2f(250, 0);
-    glVertex2f(250, 250);
-    glVertex2f(0, 250);
-    glVertex2f(0, 0);
-
-    glEnd();
-
-
-    glDisable(GL_LINE_STIPPLE);
-}
-
 void glCompCalcWidget(glCompCommon * parent, glCompCommon * child,
 		      glCompCommon * ref)
 {
@@ -315,10 +207,7 @@ void glCompCalcWidget(glCompCommon * parent, glCompCommon * child,
 	child->refPos.y = child->pos.y;
 	return;
     }
-    if (parent->borderType == glBorderNone)
-	borderWidth = 0.0f;
-    else
-	borderWidth = parent->borderWidth;
+    borderWidth = parent->borderWidth;
     if (child->align != glAlignNone)	//if alignment, make sure width and height is no greater than parent
     {
 	if (child->width > parent->width)
@@ -421,15 +310,15 @@ void glCompDrawRectangle(glCompRect * r)
 void glCompDrawRectPrism(glCompPoint * p, GLfloat w, GLfloat h, GLfloat b,
 			 GLfloat d, glCompColor * c, int bumped)
 {
-    static GLfloat color_fac;
-    static glCompPoint A, B, C, D, E, F, G, H;
+    GLfloat color_fac;
+    glCompPoint A, B, C, D, E, F, G, H;
     GLfloat dim = 1.00;
     if (!bumped) {
-	color_fac = (GLfloat) 1.3;
+	color_fac = 1.3f;
 	b = b - 2;
 	dim = 0.5;
     } else
-	color_fac = (GLfloat) 1 / (GLfloat) 1.3;
+	color_fac = 1.0f / 1.3f;
 
 
     A.x = p->x;
@@ -473,15 +362,6 @@ void glCompDrawRectPrism(glCompPoint * p, GLfloat w, GLfloat h, GLfloat b,
 
 }
 
-void copy_glcomp_color(glCompColor * source, glCompColor * target)
-{
-    target->R = source->R;
-    target->G = source->G;
-    target->B = source->B;
-    target->A = source->A;
-
-}
-
 GLfloat distBetweenPts(glCompPoint A,glCompPoint B,float R)
 {
     GLfloat rv=0;	
@@ -494,8 +374,13 @@ GLfloat distBetweenPts(glCompPoint A,glCompPoint B,float R)
 
 int is_point_in_rectangle(float X, float Y, float RX, float RY, float RW,float RH)
 {
-    if ((X >= RX) && (X <= (RX + RW)) && (Y >= RY) && (Y <= (RY + RH)))
+    if (X >= RX && X <= RX + RW && Y >= RY && Y <= RY + RH)
 	return 1;
     else
 	return 0;
 }
+
+/**
+ * @dir lib/glcomp
+ * @brief OpenGL GUI for cmd/smyrna
+ */
