@@ -10,12 +10,9 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include <vector>
 
-void nearest_neighbor_graph_ann(int nPts, int k, double eps, double *x, int *nz0, int **irn0, int **jcn0, double **val0);
-
-#ifdef __cplusplus
-}
-#endif
+void nearest_neighbor_graph_ann(int nPts, int k, double eps, double *x,
+                                int &nz0, std::vector<int> &irn,
+                                std::vector<int> &jcn,
+                                std::vector<double> &val);
