@@ -28,7 +28,9 @@
 #include <ortho/maze.h>
 #include <ortho/fPQ.h>
 #include <ortho/ortho.h>
-#include <common/memory.h>
+#include <cgraph/alloc.h>
+#include <cgraph/exit.h>
+#include <cgraph/unused.h>
 #include <common/geomprocs.h>
 #include <common/globals.h>
 #include <common/render.h>
@@ -39,8 +41,15 @@ typedef struct {
 } epair_t;
 
 #ifdef DEBUG
-static void emitSearchGraph (FILE* fp, sgraph* sg);
-static void emitGraph (FILE* fp, maze* mp, size_t n_edges, route* route_list, epair_t[]);
+#define DEBUG_FN /* nothing */
+#else
+#define DEBUG_FN UNUSED
+#endif
+
+static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg);
+static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
+                               route *route_list, epair_t[]);
+#ifdef DEBUG
 int odb_flags;
 #endif
 
@@ -114,14 +123,12 @@ setSeg (segment* sp, bool dir, double fix, double b1, double b2, int l1, int l2)
 	sp->p.p2 = b2;
 	sp->l1 = l1;
 	sp->l2 = l2;
-	sp->flipped = 0;
     }
     else {
 	sp->p.p2 = b1;
 	sp->p.p1 = b2;
 	sp->l2 = l1;
 	sp->l1 = l2;
-	sp->flipped = 1;
     }
 }
 
@@ -153,7 +160,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
     for (ptr = fst; ptr; ptr = N_DAD(ptr)) sz++;
     rte.n = 0;
     assert(sz >= 2);
-    rte.segs = N_NEW(sz-2, segment);  /* at most sz-2 segments */
+    rte.segs = gv_calloc(sz - 2, sizeof(segment));  /* at most sz-2 segments */
 
     seg.prev = seg.next = 0;
     ptr = prev = N_DAD(fst);
@@ -335,7 +342,7 @@ addChan (Dt_t* chdict, channel* cp, double j)
     chanItem* subd = dtmatch (chdict, &j);
 
     if (!subd) {
-	subd = NEW (chanItem);
+	subd = gv_alloc(sizeof(chanItem));
 	subd->v = j;
 	subd->chans = dtopen (&chanDisc, Dtoset);
 	dtinsert (chdict, subd);
@@ -362,7 +369,7 @@ extractHChans (maze* mp)
 	    cp = nextcp;
 	}
 
-	chp = NEW(channel);
+	chp = gv_alloc(sizeof(channel));
 	chp->cp = cp;
 	chp->p.p1 = cp->bb.LL.x;
 
@@ -399,7 +406,7 @@ extractVChans (maze* mp)
 	    cp = nextcp;
 	}
 
-	chp = NEW(channel);
+	chp = gv_alloc(sizeof(channel));
 	chp->cp = cp;
 	chp->p.p1 = cp->bb.LL.y;
 
@@ -502,8 +509,6 @@ addNodeEdges (sgraph* sg, cell* cp, snode* np)
 #endif
 }
 
-#ifdef DEBUG
-
 #include <common/intset.h>
 static char* bendToStr (bend b)
 {
@@ -539,9 +544,7 @@ static void putSeg (FILE* fp, segment* seg)
       seg->p.p2, seg->comm_coord, bendToStr (seg->l1), bendToStr (seg->l2));
 }
 
-static void
-dumpChanG (channel* cp, int v)
-{
+static DEBUG_FN void dumpChanG(channel *cp, int v) {
   int k;
   intitem* ip;
   Dt_t* adj;
@@ -560,7 +563,6 @@ dumpChanG (channel* cp, int v)
     }
   }
 }
-#endif
 
 static void
 assignTrackNo (Dt_t* chans)
@@ -649,67 +651,60 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
     if(S1->p.p1<S2->p.p1&&S2->p.p1<S1->p.p2)
 	return overlapSeg (S1, S2, T1, T2);
 	/* left endpoint of S1 inside S2 */
-    else if(S2->p.p1<S1->p.p1&&S1->p.p1<S2->p.p2)
+    if (S2->p.p1 < S1->p.p1 && S1->p.p1 < S2->p.p2)
 	return -1*overlapSeg (S2, S1, T1, T2);
-    else if(S1->p.p1==S2->p.p1) {
+    if (S1->p.p1 == S2->p.p1) {
 	if(S1->p.p2==S2->p.p2) {
 	    if (S1->l1 == S2->l1 && S1->l2 == S2->l2)
 		return 0;
-	    else if (S2->l1==S2->l2) {
+	    if (S2->l1 == S2->l2) {
 		if (S2->l1 == T1) return 1;
-		else if (S2->l1 == T2) return -1;
-		else if (S1->l1 != T1 && S1->l2 != T1) return 1;
-		else if (S1->l1 != T2 && S1->l2 != T2) return -1;
-		else return 0;
+		if (S2->l1 == T2) return -1;
+		if (S1->l1 != T1 && S1->l2 != T1) return 1;
+		if (S1->l1 != T2 && S1->l2 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l1 == T1 && S2->l2 == T2) {
+	    if (S2->l1 == T1 && S2->l2 == T2) {
 		if (S1->l1 != T1 && S1->l2 == T2) return 1;
-		else if (S1->l1 == T1 && S1->l2 != T2) return -1;
-		else return 0;
+		if (S1->l1 == T1 && S1->l2 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l2 == T1 && S2->l1 == T2) {
+	    if (S2->l2 == T1 && S2->l1 == T2) {
 		if (S1->l2 != T1 && S1->l1 == T2) return 1;
-		else if (S1->l2 == T1 && S1->l1 != T2) return -1;
-		else return 0;
+		if (S1->l2 == T1 && S1->l1 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l1 == B_NODE && S2->l2 == T1) {
+	    if (S2->l1 == B_NODE && S2->l2 == T1) {
 		return ellSeg (S1->l1, S1->l2, T1);
 	    }
-	    else if (S2->l1 == B_NODE && S2->l2 == T2) {
+	    if (S2->l1 == B_NODE && S2->l2 == T2) {
 		return -1*ellSeg (S1->l1, S1->l2, T2);
 	    }
-	    else if (S2->l1 == T1 && S2->l2 == B_NODE) {
+	    if (S2->l1 == T1 && S2->l2 == B_NODE) {
 		return ellSeg (S1->l2, S1->l1, T1);
 	    }
-	    else { /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
-		return -1*ellSeg (S1->l2, S1->l1, T2);
-	    }
+	    /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
+	    return -1 * ellSeg(S1->l2, S1->l1, T2);
 	}
-	else if(S1->p.p2<S2->p.p2) {
+	if (S1->p.p2 < S2->p.p2) {
 	    if(S1->l2==T1)
 		return eqEndSeg (S2->l1, S1->l1, T1, T2);
-	    else
-		return -1*eqEndSeg (S2->l1, S1->l1, T1, T2);
-	}
-	else { /* S1->p.p2>S2->p.p2 */
-	    if(S2->l2==T2)
-		return eqEndSeg (S1->l1, S2->l1, T1, T2);
-	    else
-		return -1*eqEndSeg (S1->l1, S2->l1, T1, T2);
+	    return -1 * eqEndSeg(S2->l1, S1->l1, T1, T2);
 	}
+	/* S1->p.p2>S2->p.p2 */
+	if (S2->l2 == T2)
+	    return eqEndSeg(S1->l1, S2->l1, T1, T2);
+	return -1 * eqEndSeg(S1->l1, S2->l1, T1, T2);
     }
-    else if(S1->p.p2==S2->p.p1) {
+    if (S1->p.p2 == S2->p.p1) {
 	if (S1->l2 == S2->l1) return 0;
-	else if (S1->l2 == T2) return 1;
-	else return -1;
+	if (S1->l2 == T2) return 1;
+	return -1;
     }
-    else { /* S1->p.p1==S2->p.p2 */
-	if (S1->l1 == S2->l2) return 0;
-	else if (S1->l1 == T2) return 1;
-	else return -1;
-    }
-    assert(0);
-    return 0;
+    /* S1->p.p1==S2->p.p2 */
+    if (S1->l1 == S2->l2) return 0;
+    if (S1->l1 == T2) return 1;
+    return -1;
 }
 
 /* Function seg_cmp returns
@@ -1167,7 +1162,7 @@ attachOrthoEdges(maze* mp, size_t n_edges, route* route_list, splineInfo *sinfo,
 	size_t npts = 1 + 3*rte.n;
 	if (npts > splsz) {
 		free (ispline);
-		ispline = N_GNEW(npts, pointf);
+		ispline = gv_calloc(npts, sizeof(pointf));
 		splsz = npts;
 	}
 	    
@@ -1206,7 +1201,7 @@ attachOrthoEdges(maze* mp, size_t n_edges, route* route_list, splineInfo *sinfo,
 	    fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
 	clip_and_install(e, aghead(e), ispline, npts, sinfo);
 	if (doLbls && (lbl = ED_label(e)) && !lbl->set)
-	    addEdgeLabels(e, p1, q1);
+	    addEdgeLabels(e);
     }
     free(ispline);
 }
@@ -1224,19 +1219,19 @@ static int edgecmp(epair_t* e0, epair_t* e1)
     return e0->d - e1->d;
 }
 
-static boolean spline_merge(node_t * n)
+static bool spline_merge(node_t * n)
 {
     (void)n;
-    return FALSE;
+    return false;
 }
 
-static boolean swap_ends_p(edge_t * e)
+static bool swap_ends_p(edge_t * e)
 {
     (void)e;
-    return FALSE;
+    return false;
 }
 
-static splineInfo sinfo = { swap_ends_p, spline_merge, 1, 1 };
+static splineInfo sinfo = { swap_ends_p, spline_merge, true, true };
 
 /* orthoEdges:
  * For edges without position information, construct an orthogonal routing.
@@ -1254,7 +1249,7 @@ orthoEdges (Agraph_t* g, int doLbls)
     Agedge_t* e;
     snode* sn;
     snode* dn;
-    epair_t* es = N_GNEW(agnedges(g), epair_t);
+    epair_t* es = gv_calloc(agnedges(g), sizeof(epair_t));
     cell* start;
     cell* dest;
     PointSet* ps = NULL;
@@ -1295,7 +1290,7 @@ orthoEdges (Agraph_t* g, int doLbls)
 	agerr(AGWARN, "Orthogonal edges do not currently handle edge labels. Try using xlabels.\n");
 	doLbls = 0;
     }
-    mp = mkMaze (g, doLbls);
+    mp = mkMaze(g);
     sg = mp->sg;
 #ifdef DEBUG
     if (odb_flags & ODB_SGRAPH) emitSearchGraph (stderr, sg);
@@ -1324,7 +1319,7 @@ orthoEdges (Agraph_t* g, int doLbls)
 	}
     }
 
-    route_list = N_NEW (n_edges, route);
+    route_list = gv_calloc(n_edges, sizeof(route));
 
     qsort(es, n_edges, sizeof(epair_t), (qsort_cmpf) edgecmp);
 
@@ -1378,7 +1373,6 @@ orthofinish:
     free (es);
 }
 
-#ifdef DEBUG
 #include <common/arith.h>
 #define TRANS 10
 
@@ -1417,7 +1411,7 @@ static char* prolog2 =
 static char* epilog2 =
 "showpage\n\
 %%%%Trailer\n\
-%%%%BoundingBox: %d %d %d %d\n";
+%%%%BoundingBox: %.f %.f %.f %.f\n";
 
 static point
 coordOf (cell* cp, snode* np)
@@ -1441,7 +1435,7 @@ coordOf (cell* cp, snode* np)
     }
     else {
 	agerr (AGERR, "Node not adjacent to cell -- Aborting\n");
-	exit(EXIT_FAILURE);
+	graphviz_exit(EXIT_FAILURE);
     }
     return p;
 }
@@ -1499,9 +1493,17 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
     return bb;
 }
 
-static void
-emitSearchGraph (FILE* fp, sgraph* sg)
-{
+/**
+ * @brief dumps in dot format @ref snode::cells and @ref edges of
+ * @ref sgraph for debugging
+ *
+ * The routine uses coordinates of @ref cells calculated
+ * from @ref gcells.
+ * Coordinates of @ref gcellg are calculated by original
+ * specified graph layout engine.
+ */
+
+static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg) {
     cell* cp;
     snode* np;
     sedge* ep;
@@ -1509,6 +1511,7 @@ emitSearchGraph (FILE* fp, sgraph* sg)
     int i;
     fputs ("graph G {\n", fp);
     fputs (" node[shape=point]\n", fp);
+    fputs (" layout=neato\n", fp);
     for (i = 0; i < sg->nnodes; i++) {
 	np = sg->nodes+i;
 	cp = np->cells[0];
@@ -1521,20 +1524,18 @@ emitSearchGraph (FILE* fp, sgraph* sg)
 	    if (IsNode(cp)) cp = np->cells[1];
 	    p = coordOf (cp, np);
 	}
-	fprintf (fp, "  %d [pos=\"%d,%d\"]\n", i, p.x, p.y);
+	fprintf (fp, "  %d [pos=\"%d,%d!\"]\n", i, p.x, p.y);
     }
     for (i = 0; i < sg->nedges; i++) {
 	ep = sg->edges+i;
-	fprintf (fp, "  %d -- %d[len=\"%f\"]\n", ep->v1, ep->v2, ep->weight);
+	fprintf (fp, "  %d -- %d[label=\"%f\"]\n", ep->v1, ep->v2, ep->weight);
     }
     fputs ("}\n", fp);
 }
 
-static void
-emitGraph (FILE* fp, maze* mp, size_t n_edges, route* route_list, epair_t es[])
-{
+static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
+                               route *route_list, epair_t es[]) {
     boxf bb, absbb;
-    box bbox;
 
     absbb.LL.x = absbb.LL.y = MAXDOUBLE;
     absbb.UR.x = absbb.UR.y = -MAXDOUBLE;
@@ -1562,10 +1563,10 @@ emitGraph (FILE* fp, maze* mp, size_t n_edges, route* route_list, epair_t es[])
       absbb.UR.y = MAX(absbb.UR.y, bb.UR.y);
     }
 
+    boxf bbox;
     bbox.LL.x = absbb.LL.x + TRANS;
     bbox.LL.y = absbb.LL.y + TRANS;
     bbox.UR.x = absbb.UR.x + TRANS;
     bbox.UR.y = absbb.UR.y + TRANS;
     fprintf (fp, epilog2, bbox.LL.x, bbox.LL.y,  bbox.UR.x, bbox.UR.y);
 }
-#endif
