@@ -10,38 +10,34 @@
 
 #pragma once
 
-#define _BLD_pathplan 1
-
 #include "pathplan.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef NOT
-#define NOT(x)	(!(x))
-#endif
 #ifndef FALSE
 #define FALSE	0
-#define TRUE	(NOT(FALSE))
+#define TRUE	(!FALSE)
 #endif
 
-/*visual studio*/
-#ifdef _WIN32
-#ifndef PATHPLAN_EXPORTS
+#ifdef GVDLL
+#ifdef PATHPLAN_EXPORTS
+#define PATHUTIL_API __declspec(dllexport)
+#else
 #define PATHUTIL_API __declspec(dllimport)
 #endif
 #endif
-/*end visual studio*/
+
 #ifndef PATHUTIL_API
-#define PATHUTIL_API extern
+#define PATHUTIL_API /* nothing */
 #endif
 	typedef double COORD;
     PATHUTIL_API COORD area2(Ppoint_t, Ppoint_t, Ppoint_t);
     PATHUTIL_API int wind(Ppoint_t a, Ppoint_t b, Ppoint_t c);
     PATHUTIL_API COORD dist2(Ppoint_t, Ppoint_t);
 
-    int in_poly(Ppoly_t argpoly, Ppoint_t q);
+    PATHUTIL_API int in_poly(Ppoly_t argpoly, Ppoint_t q);
 
 #undef PATHUTIL_API
 #ifdef __cplusplus
