@@ -12,8 +12,6 @@
 
 #include <sparse/SparseMatrix.h>
 
-enum {SOLVE_METHOD_CG, SOLVE_METHOD_JACOBI};
-
 typedef struct Operator_struct *Operator;
 
 struct Operator_struct {
@@ -23,7 +21,7 @@ struct Operator_struct {
 
 double cg(Operator Ax, Operator precond, int n, int dim, double *x0, double *rhs, double tol, int maxit);
 
-double SparseMatrix_solve(SparseMatrix A, int dim, double *x0, double *rhs, double tol, int maxit, int method, int *flag);
+double SparseMatrix_solve(SparseMatrix A, int dim, double *x0, double *rhs, double tol, int maxit);
 
 Operator Operator_uniform_stress_matmul(SparseMatrix A, double alpha);
 
