@@ -48,27 +48,15 @@ extern "C" {
 
 #ifdef HAVE_SYS_STAT_H
 #	include	<sys/stat.h>
-#	undef HAVE_SYS_STAT_H
-#	define HAVE_SYS_STAT_H 1
-#else
-#	ifdef HAVE_STAT_H
-#		include	<stat.h>
-#		define	HAVE_SYS_STAT_H	1
-#	endif
 #endif /*HAVE_SYS_STAT_H*/
 
 #include	<fcntl.h>
 
-#ifdef HAVE_UNISTD_H
 #include	<unistd.h>
-#endif
 
 #include	<errno.h>
 #include	<ctype.h>
 
-#undef SF_MTSAFE		/* no need to worry about thread-safety */
-#define SF_MTSAFE		0
-
 #define SFMTXSTART(f,v)		{ if(!f) return(v); }
 #define SFMTXRETURN(f,v)	{ return(v); }
 
@@ -85,9 +73,6 @@ extern "C" {
 #endif
 #endif
 
-/* to get rid of pesky compiler warnings */
-#define NOTUSED(x)	(void)(x)
-
 /* Private flags in the "bits" field */
 #define SF_MMAP		00000001	/* in memory mapping mode               */
 #define SF_BOTH		00000002	/* both read/write                      */
@@ -116,7 +101,6 @@ extern "C" {
 #define SF_LOCAL	00100000u	/* sentinel for a local call            */
 
 /* short-hands */
-#define NIL(t)		((t)0)
 #ifndef uchar
 #define uchar		unsigned char
 #endif
@@ -130,8 +114,6 @@ extern "C" {
 #define ushort		unsigned short
 #endif
 
-#define SECOND		1000	/* millisecond units */
-
 /* macros do determine stream types from Stat_t data */
 #ifndef S_IFMT
 #define S_IFMT	0
@@ -145,9 +127,6 @@ extern "C" {
 #ifndef S_IFCHR
 #define S_IFCHR	0
 #endif
-#ifndef S_IFIFO
-#define S_IFIFO	0
-#endif
 
 #ifndef S_ISDIR
 #define S_ISDIR(m)	(((m)&S_IFMT) == S_IFDIR)
@@ -159,14 +138,6 @@ extern "C" {
 #define S_ISCHR(m)	(((m)&S_IFMT) == S_IFCHR)
 #endif
 
-#ifndef S_ISFIFO
-#	ifdef S_IFIFO
-#		define S_ISFIFO(m)	(((m)&S_IFMT) == S_IFIFO)
-#	else
-#		define S_ISFIFO(m)	(0)
-#	endif
-#endif
-
 #if defined(S_IRUSR) && defined(S_IWUSR) && defined(S_IRGRP) && defined(S_IWGRP) && defined(S_IROTH) && defined(S_IWOTH)
 #define SF_CREATMODE	(S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH)
 #else
@@ -187,19 +158,16 @@ extern "C" {
 #define EINVAL	22
 #endif
 /* function to get the decimal point for local environment */
-#ifdef MAXFLOAT			/* we don't need these, so we zap them to avoid compiler warnings */
-#undef MAXFLOAT
-#endif
 #include	<locale.h>
 #define SFSETLOCALE(decimal,thousand) \
-	{ struct lconv*	lv; \
+	{ struct lconv*	lv_; \
 	  if((decimal) == 0) \
 	  { (decimal) = '.'; \
-	    if((lv = localeconv())) \
-	    { if(lv->decimal_point && lv->decimal_point[0]) \
-	    	(decimal) = lv->decimal_point[0]; \
-	      if(lv->thousands_sep && lv->thousands_sep[0]) \
-	    	(thousand) = lv->thousands_sep[0]; \
+	    if((lv_ = localeconv())) \
+	    { if(lv_->decimal_point && lv_->decimal_point[0]) \
+	    	(decimal) = lv_->decimal_point[0]; \
+	      if(lv_->thousands_sep && lv_->thousands_sep[0]) \
+	    	(thousand) = lv_->thousands_sep[0]; \
 	    } \
 	  } \
 	}
@@ -222,17 +190,6 @@ extern "C" {
 	uchar data[1];		/* data buffer                  */
     };
 
-/* co-process structure */
-    typedef struct _sfproc_s Sfproc_t;
-    struct _sfproc_s {
-	int pid;		/* process id                   */
-	uchar *rdata;		/* read data being cached       */
-	int ndata;		/* size of cached data          */
-	int size;		/* buffer size                  */
-	int file;		/* saved file descriptor        */
-	int sigp;		/* sigpipe protection needed    */
-    };
-
 /* extensions to sfvprintf/sfvscanf */
 #define FP_SET(fp,fn)	(fp < 0 ? (fn += 1) : (fn = fp) )
 #define FP_WIDTH	0
@@ -301,7 +258,6 @@ extern "C" {
 	 (sz == 64 && sz == sizeof(type)*CHAR_BIT) )
 
 /* format flags&types, must coexist with those in sfio.h */
-#define SFFMT_FORBIDDEN 00077777777	/* for sfio.h only      */
 #define SFFMT_EFORMAT	01000000000	/* sfcvt converting %e  */
 #define SFFMT_MINUS	02000000000	/* minus sign           */
 
@@ -343,7 +299,6 @@ extern "C" {
 
 /* grain size for buffer increment */
 #define SF_GRAIN	1024
-#define SF_PAGE		((ssize_t)(SF_GRAIN*sizeof(int)*2))
 
 /* when the buffer is empty, certain io requests may be better done directly
    on the given application buffers. The below condition determines when.
@@ -377,7 +332,7 @@ extern "C" {
 #define SFSYNC(f)	(SETLOCAL(f),sfsync(f))
 #define SFCLOSE(f)	(SETLOCAL(f),sfclose(f))
 #define SFFLSBUF(f,n)	(SETLOCAL(f),_sfflsbuf(f,n))
-#define SFFILBUF(f,n)	(SETLOCAL(f),_sffilbuf(f,n))
+#define SFFILBUF(f)	(SETLOCAL(f), _sffilbuf(f ,-1))
 #define SFSETBUF(f,s,n)	(SETLOCAL(f),sfsetbuf(f,s,n))
 #define SFWRITE(f,s,n)	(SETLOCAL(f),sfwrite(f,s,n))
 #define SFREAD(f,s,n)	(SETLOCAL(f),sfread(f,s,n))
@@ -387,8 +342,8 @@ extern "C" {
 /* lock/open a stream */
 #define SFMODE(f,l)	((f)->mode & ~(SF_RV|SF_RC|((l) ? SF_LOCK : 0)) )
 #define SFLOCK(f,l)	(void)((f)->mode |= SF_LOCK, (f)->endr = (f)->endw = (f)->data)
-#define _SFOPENRD(f)	((f)->endr = ((f)->flags&SF_MTSAFE) ? (f)->data : (f)->endb)
-#define _SFOPENWR(f)	((f)->endw = ((f)->flags&(SF_MTSAFE|SF_LINE)) ? (f)->data : (f)->endb)
+#define _SFOPENRD(f)	((f)->endr = (f)->endb)
+#define _SFOPENWR(f)	((f)->endw = ((f)->flags&SF_LINE) ? (f)->data : (f)->endb)
 #define _SFOPEN(f)	((f)->mode == SF_READ  ? _SFOPENRD(f) : \
 			 (f)->mode == SF_WRITE ? _SFOPENWR(f) : \
 			 ((f)->endw = (f)->endr = (f)->data) )
@@ -428,7 +383,7 @@ extern "C" {
 /* fast peek of a stream */
 #define _SFAVAIL(f,s,n)	((n) = (f)->endb - ((s) = (f)->next) )
 #define SFRPEEK(f,s,n)	(_SFAVAIL(f,s,n) > 0 ? (n) : \
-				((n) = SFFILBUF(f,-1), (s) = (f)->next, (n)) )
+				((n) = SFFILBUF(f), (s) = (f)->next, (n)) )
 #define SFWPEEK(f,s,n)	(_SFAVAIL(f,s,n) > 0 ? (n) : \
 				((n) = SFFLSBUF(f,-1), (s) = (f)->next, (n)) )
 
@@ -439,9 +394,9 @@ extern "C" {
 #define CLOSE(f)	{ while(close(f) < 0 && errno == EINTR) errno = 0; }
 
 /* string stream extent */
-#define SFSTRSIZE(f)	{ Sfoff_t s = (f)->next - (f)->data; \
-			  if(s > (f)->here) \
-			    { (f)->here = s; if(s > (f)->extent) (f)->extent = s; } \
+#define SFSTRSIZE(f)	{ Sfoff_t s_ = (f)->next - (f)->data; \
+			  if(s_ > (f)->here) \
+			    { (f)->here = s_; if(s_ > (f)->extent) (f)->extent = s_; } \
 			}
 
 /* control flags for open() */
@@ -476,7 +431,6 @@ extern "C" {
 
 /* floating point to ascii conversion */
 #define SF_MAXEXP10	6
-#define SF_MAXPOW10	(1 << SF_MAXEXP10)
 #define SF_FDIGITS	256	/* max allowed fractional digits */
 #define SF_IDIGITS	1024	/* max number of digits in int part */
 #define SF_MAXDIGITS	(((SF_FDIGITS+SF_IDIGITS)/sizeof(int) + 1)*sizeof(int))
@@ -556,11 +510,9 @@ extern "C" {
 	  } \
 	}
 
-/* handy functions */
+// handy function
 #undef min
-#undef max
 #define min(x,y)	((x) < (y) ? (x) : (y))
-#define max(x,y)	((x) > (y) ? (x) : (y))
 
 /* fast functions for memory copy and memory clear */
 #define memclear(s,n)	memset((s),'\0',(n))
@@ -572,40 +524,11 @@ extern "C" {
     extern Sfextern_t _Sfextern;
     extern Sftab_t _Sftable;
 
-    extern int _sfpopen(Sfio_t *, int, int, int);
-    extern int _sfpclose(Sfio_t *);
     extern int _sfmode(Sfio_t *, int, int);
-    extern int _sftype(const char *, int *, int *);
     extern int _sfexcept(Sfio_t *, int, ssize_t, Sfdisc_t *);
     extern Sfrsrv_t *_sfrsrv(Sfio_t *, ssize_t);
     extern int _sfsetpool(Sfio_t *);
     extern char *_sfcvt(void *, int, int *, int *, int);
-    extern char **_sfgetpath(char *);
-
-#ifdef _WIN32
-#undef SF_ERROR
-#include <io.h>
-#define SF_ERROR	0000400	/* an error happened                    */
-#else
-#ifndef HAVE_UNISTD_H
-    extern int close(int);
-    extern ssize_t read(int, void *, size_t);
-    extern ssize_t write(int, const void *, size_t);
-    extern off_t lseek(int, off_t, int);
-    extern int dup(int);
-    extern int isatty(int);
-    extern int wait(int *);
-    extern int pipe(int *);
-    extern int access(const char *, int);
-    extern uint sleep(uint);
-    extern int execl(const char *, const char *, ...);
-
-#endif /*HAVE_UNISTD_H*/
-#endif /* _WIN32 */
-
-#ifdef HAVE_SYS_STAT_H
-    extern int fstat(int, Stat_t *);
-#endif
 
 #ifdef __cplusplus
 }
