@@ -9,30 +9,24 @@
  *************************************************************************/
 
 #include <stddef.h>
-
-#if defined(__STDPP__directive) && defined(__STDPP__hide)
-__STDPP__directive pragma pp:hide getpagesize
-#else
-#define getpagesize	______getpagesize
-#endif
-
 #include	<sfio/sfhdr.h>
+#include <unistd.h>
 
-#if defined(__STDPP__directive) && defined(__STDPP__hide)
-__STDPP__directive pragma pp:nohide getpagesize
+#ifdef _WIN32
+#include <windows.h>
+#include <sysinfoapi.h>
+#endif
+
+static ssize_t get_page_size(void) {
+#ifdef _WIN32
+  SYSTEM_INFO info;
+  GetSystemInfo(&info);
+  return (ssize_t)info.dwPageSize;
 #else
-#undef	getpagesize
+  return (ssize_t)sysconf(_SC_PAGESIZE);
 #endif
-
-#ifdef HAVE_GETPAGESIZE
-#ifdef __cplusplus
-extern "C" {
-#endif
-	extern int getpagesize(void);
-#ifdef __cplusplus
 }
-#endif
-#endif
+
 /*	Set a (new) buffer for a stream.
 **	If size < 0, it is assigned a suitable value depending on the
 **	kind of stream. The actual buffer size allocated is dependent
@@ -69,7 +63,7 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
     if (size == 0 && buf) {	/* special case to get buffer info */
 	_Sfi = f->val =
 	    (f->bits & SF_MMAP) ? (f->endb - f->data) : f->size;
-	SFMTXRETURN(f, (void *) f->data);
+	SFMTXRETURN(f, f->data);
     }
 
     /* cleanup actions already done, don't allow write buffering any more */
@@ -90,11 +84,6 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
     else {
 	int rv;
 
-	/* make sure there is no hidden read data */
-	if (f->proc && (f->flags & SF_READ) && (f->mode & SF_WRITE) &&
-	    _sfmode(f, SF_READ, local) < 0)
-	    SFMTXRETURN(f, NULL);
-
 	/* synchronize first */
 	SFLOCK(f, local);
 	rv = SFSYNC(f);
@@ -135,12 +124,17 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
 	st.st_mode = 0;
 
 	/* if has discipline, set size by discipline if possible */
-	if (!HAVE_SYS_STAT_H || disc) {
-	    if ((f->here = SFSK(f, (Sfoff_t) 0, SEEK_CUR, disc)) < 0)
+#ifdef HAVE_SYS_STAT_H
+  enum { have_sys_stat_h = 1 };
+#else
+  enum { have_sys_stat_h = 0 };
+#endif
+	if (!have_sys_stat_h || disc) {
+	    if ((f->here = SFSK(f, 0, SEEK_CUR, disc)) < 0)
 		goto unseekable;
 	    else {
 		Sfoff_t e;
-		if ((e = SFSK(f, (Sfoff_t) 0, SEEK_END, disc)) >= 0)
+		if ((e = SFSK(f, 0, SEEK_END, disc)) >= 0)
 		    f->extent = e > f->here ? e : f->here;
 		(void) SFSK(f, f->here, SEEK_SET, disc);
 		goto setbuf;
@@ -152,7 +146,7 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
 	    f->here = -1;
 	else {
 	    if (S_ISREG(st.st_mode) || S_ISDIR(st.st_mode))
-		f->here = SFSK(f, (Sfoff_t) 0, SEEK_CUR, f->disc);
+		f->here = SFSK(f, 0, SEEK_CUR, f->disc);
 	    else
 		f->here = -1;
 	}
@@ -190,19 +184,12 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
 #endif
 		    errno = oerrno;
 		}
-
-		/* initialize side buffer for r+w unseekable streams */
-		if (!f->proc && (f->bits & SF_BOTH))
-		    (void) _sfpopen(f, -1, -1, 0);
 	    }
 	}
 
 	/* set page size, this is also the desired default buffer size */
 	if (_Sfpage <= 0) {
-#ifdef HAVE_GETPAGESIZE
-	    if ((_Sfpage = (size_t) getpagesize()) <= 0)
-#endif
-		_Sfpage = SF_PAGE;
+		_Sfpage = get_page_size();
 	}
     }
 
@@ -229,7 +216,7 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
     sf_malloc = 0;
     if (size > 0 && !buf && !(f->bits & SF_MMAP)) {	/* try to allocate a buffer */
 	if (obuf && size == (size_t) osize && init) {
-	    buf = (void *) obuf;
+	    buf = obuf;
 	    obuf = NULL;
 	    sf_malloc = (oflags & SF_MALLOC);
 	}
@@ -247,7 +234,7 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
 
     if (size == 0 && !(f->flags & SF_STRING) && !(f->bits & SF_MMAP) && (f->mode & SF_READ)) {	/* use the internal buffer */
 	size = sizeof(f->tiny);
-	buf = (void *) f->tiny;
+	buf = f->tiny;
     }
 
     /* set up new buffer */
@@ -276,5 +263,5 @@ void *sfsetbuf(Sfio_t * f, void * buf, size_t size)
 
     SFOPEN(f, local);
 
-    SFMTXRETURN(f, (void *) obuf);
+    SFMTXRETURN(f, obuf);
 }
