@@ -11,6 +11,7 @@
 #include <inttypes.h>
 #include	<limits.h>
 #include	<sfio/sfhdr.h>
+#include	<stdbool.h>
 #include	<stddef.h>
 
 /*	The main engine for reading formatted data
@@ -62,13 +63,13 @@ static void _sfbuf(Sfio_t * f, int *rs)
     if (f->next >= f->endb) {
 	if (*rs > 0) {		/* try peeking for a share stream if possible */
 	    f->mode |= SF_RV;
-	    if (SFFILBUF(f, -1) > 0) {
+	    if (SFFILBUF(f) > 0) {
 		f->mode |= SF_PEEK;
 		return;
 	    }
 	    *rs = -1;		/* can't peek, back to normal reads */
 	}
-	(void) SFFILBUF(f, -1);
+	(void) SFFILBUF(f);
     }
 }
 
@@ -202,10 +203,9 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 		    if (*t_str != '*')
 			n_str = (form - 1) - t_str;
 		    else {
-			t_str = (*_Sffmtintf) (t_str + 1, &n);
+			t_str = _Sffmtintf(t_str + 1, &n);
 			if (*t_str == '$') {
-			    if (!fp && !(fp = (*_Sffmtposf)
-					 (f, oform, oargs, 1)))
+			    if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 1)))
 				goto pop_fmt;
 			    n = FP_SET(n, argn);
 			} else
@@ -217,7 +217,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 			} else if (ft && ft->extf) {
 			    FMTSET(ft, form, args,
 				   LEFTP, 0, 0, 0, 0, 0, NULL, 0);
-			    n = (*ft->extf)(&argv, ft);
+			    n = ft->extf(&argv, ft);
 			    if (n < 0)
 				goto pop_fmt;
 			    if (!(ft->flags & SFFMT_VALUE))
@@ -241,14 +241,14 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 
 	case '.':		/* width & base */
 	    dot += 1;
-	    if (isdigit(*form)) {
+	    if (isdigit((int)*form)) {
 		fmt = *form++;
 		goto dot_size;
 	    } else if (*form == '*') {
-		form = (*_Sffmtintf) (form + 1, &n);
+		form = _Sffmtintf(form + 1, &n);
 		if (*form == '$') {
 		    form += 1;
-		    if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 1)))
+		    if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 1)))
 			goto pop_fmt;
 		    n = FP_SET(n, argn);
 		} else
@@ -259,7 +259,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0,
 			   NULL, 0);
-		    if ((*ft->extf)(&argv, ft) < 0)
+		    if (ft->extf(&argv, ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
 			v = argv.i;
@@ -284,12 +284,12 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 	case '8':
 	case '9':
 	  dot_size:
-	    for (v = fmt - '0'; isdigit(*form); ++form)
+	    for (v = fmt - '0'; isdigit((int)*form); ++form)
 		v = v * 10 + (*form - '0');
 
 	    if (*form == '$') {
 		form += 1;
-		if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 1)))
+		if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 1)))
 		    goto pop_fmt;
 		argp = v - 1;
 		goto loop_flags;
@@ -305,14 +305,14 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 	case 'I':		/* object size */
 	    size = 0;
 	    flags = (flags & ~SFFMT_TYPES) | SFFMT_IFLAG;
-	    if (isdigit(*form)) {
+	    if (isdigit((int)*form)) {
 		for (n = *form; isdigit(n); n = *++form)
 		    size = size * 10 + (n - '0');
 	    } else if (*form == '*') {
-		form = (*_Sffmtintf) (form + 1, &n);
+		form = _Sffmtintf(form + 1, &n);
 		if (*form == '$') {
 		    form += 1;
-		    if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 1)))
+		    if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 1)))
 			goto pop_fmt;
 		    n = FP_SET(n, argn);
 		} else
@@ -323,7 +323,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, 'I', sizeof(int), 0, 0, 0, 0,
 			   NULL, 0);
-		    if ((*ft->extf)(&argv, ft) < 0)
+		    if (ft->extf(&argv, ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
 			size = argv.i;
@@ -402,7 +402,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 		   n_str);
 	    SFEND(f);
 	    SFOPEN(f, 0);
-	    v = (*ft->extf)(&argv, ft);
+	    v = ft->extf(&argv, ft);
 	    SFLOCK(f, 0);
 	    SFBUF(f);
 
@@ -425,15 +425,14 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 
 	if (fmt == '!') {
 	    if (!fp)
-		fp = (*_Sffmtposf) (f, oform, oargs, 1);
+		fp = _Sffmtposf(f, oform, oargs, 1);
 	    else
 		goto pop_fmt;
 
 	    if (!(argv.ft = va_arg(args, Sffmt_t *)))
 		continue;
 	    if (!argv.ft->form && ft) {	/* change extension functions */
-		if (ft->eventf &&
-		    (*ft->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
+		if (ft->eventf && ft->eventf(f, SF_DPOP, (void *) form, ft) < 0)
 		    continue;
 		fmstk->ft = ft = argv.ft;
 	    } else {		/* stack a new environment */
@@ -501,18 +500,19 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 
 	if (_Sftype[fmt] == SFFMT_FLOAT) {
 	    char *val;
-	    int dot, exponent;
 
 	    val = accept;
 	    if (width >= SF_MAXDIGITS)
 		width = SF_MAXDIGITS - 1;
-	    dot = exponent = 0;
+	    int exponent = 0;
+	    bool seen_dot = false;
 	    do {
 		if (isdigit(inp))
 		    *val++ = inp;
 		else if (inp == '.') {	/* too many dots */
-		    if (dot++ > 0)
+		    if (seen_dot)
 			break;
+		    seen_dot = true;
 		    *val++ = '.';
 		} else if (inp == 'e' || inp == 'E') {	/* too many e,E */
 		    if (exponent++ > 0)
@@ -533,7 +533,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
 
 	    if (value) {
 		*val = '\0';
-		    argv.d = (double) strtod(accept, NULL);
+		    argv.d = strtod(accept, NULL);
 	    }
 
 	    if (value) {
@@ -731,8 +731,8 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
     while ((fm = fmstk)) {	/* pop the format stack and continue */
 	if (fm->eventf) {
 	    if (!form || !form[0])
-		(*fm->eventf) (f, SF_FINAL, NULL, ft);
-	    else if ((*fm->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
+		fm->eventf(f, SF_FINAL, NULL, ft);
+	    else if (fm->eventf(f, SF_DPOP, (void *) form, ft) < 0)
 		goto loop_fmt;
 	}
 
@@ -754,7 +754,7 @@ int sfvscanf(Sfio_t * f, const char *form, va_list args)
     free(fp);
     while ((fm = fmstk)) {
 	if (fm->eventf)
-	    (*fm->eventf) (f, SF_FINAL, NULL, fm->ft);
+	    fm->eventf(f, SF_FINAL, NULL, fm->ft);
 	fmstk = fm->next;
 	free(fm);
     }
